@@ -3,10 +3,10 @@ package Foorum::XUtils;
 use strict;
 use warnings;
 
-our $VERSION = '1.000000';
+our $VERSION = '1.000001';
 
 use YAML::XS qw/LoadFile/;    # config
-use MooseX::TheSchwartz;      # theschwartz
+use TheSchwartz::Moosified;      # theschwartz
 use DBI;
 use Template;                 # template
 use Template::Stash::XS;
@@ -111,7 +111,7 @@ sub theschwartz {
         $config->{theschwartz_pwd}  || $config->{dsn_pwd},
         { PrintError => 1, RaiseError => 1 }
     );
-    $theschwartz = MooseX::TheSchwartz->new( databases => [$dbh] );
+    $theschwartz = TheSchwartz::Moosified->new( databases => [$dbh] );
 
     return $theschwartz;
 }
@@ -147,7 +147,7 @@ generally like $c->view('TT'), yet a bit different
 
 =item theschwartz
 
-L<MooseX::TheSchwartz> ->new with correct database from $config
+L<TheSchwartz::Moosified> ->new with correct database from $config
 
 =back
 
